package languages

import (
	"fmt"
)

func init() {
	type (
		langAttr interface{}

		langName string
		langURL  string
		langDate string
	)

	name := func(s string) langName { return langName(s) }
	url := func(s string) langURL { return langURL(s) }
	date := func(s string) langDate { return langDate(s) }
	typing := func(traits ...string) TypeSystem {
		var ts TypeSystem
		for _, v := range traits {
			switch v {
			case "strong":
				ts.Strictness = TypeStrictnessStrong
			case "weak":
				ts.Strictness = TypeStrictnessWeak
			case "static":
				ts.Checking = TypeCheckingStatic
			case "dynamic":
				ts.Checking = TypeCheckingDynamic
			case "mixed":
				ts.Checking = TypeCheckingMixed
			default:
				panic(fmt.Sprintf("unknown type system trait: %s", v))
			}
		}
		return ts
	}

	progLangList := [][]langAttr{
		{
			name(".QL"),
			url("https://en.wikipedia.org/wiki/.QL"),
		},

		{
			name("0815"),
			url("http://paulo-jorente.de/poncho/esolang/0815/"),
		},

		{
			name("360 Assembly"),
		},

		{
			name("4D"),
			url("https://en.wikipedia.org/wiki/4th_Dimension_(software)"),
		},

		{
			name("4DOS Batch"),
			url("https://en.wikipedia.org/wiki/4DOS"),
		},

		{
			name("6502 Assembly"),
		},

		{
			name("6800 Assembly"),
		},

		{
			name("68000 Assembly"),
		},

		{
			name("8 1/2"),
		},

		{
			name("80386 Assembly"),
		},

		{
			name("8051 Assembly"),
		},

		{
			name("8080 Assembly"),
		},

		{
			name("8086 Assembly"),
		},

		{
			name("8th"),
			url("https://8th-dev.com/"),
		},

		{
			name("A+"),
			url("https://en.wikipedia.org/wiki/A+_(programming_language)"),
		},

		{
			name("ABAP"),
			url("https://en.wikipedia.org/wiki/ABAP"),
		},

		{
			name("ACL2"),
		},

		{
			name("ALGOL"),
		},

		{
			name("ALGOL 60"),
		},

		{
			name("ALGOL 68"),
		},

		{
			name("ALGOL W"),
		},

		{
			name("ALGOL-M"),
		},

		{
			name("AMPL"),
		},

		{
			name("ANT"),
		},

		{
			name("ANTLR"),
		},

		{
			name("APL"),
		},

		{
			name("ARM Assembly"),
		},

		{
			name("ASP"),
		},

		{
			name("ASP.Net"),
		},

		{
			name("ATS"),
		},

		{
			name("AWK"),
		},

		{
			name("Action!"),
		},

		{
			name("ActionScript"),
			url("https://www.adobe.com/devnet/actionscript.html"),
		},

		{
			name("Ada"),
			url("https://en.wikipedia.org/wiki/Ada_(programming_language)"),
		},

		{
			name("Agda"),
			url("http://wiki.portal.chalmers.se/agda/pmwiki.php"),
		},

		{
			name("Agda2"),
		},

		{
			name("Agena"),
		},

		{
			name("Aikido"),
		},

		{
			name("Aime"),
		},

		{
			name("Algae"),
		},

		{
			name("Alice ML"),
		},

		{
			name("Alore"),
		},

		{
			name("AmbientTalk"),
		},

		{
			name("AmigaE"),
		},

		{
			name("AngelScript"),
		},

		{
			name("AntLang"),
		},

		{
			name("Anyways"),
		},

		{
			name("Apex"),
		},

		{
			name("App Inventor"),
		},

		{
			name("AppleScript"),
		},

		{
			name("Applesoft BASIC"),
		},

		{
			name("Application Master"),
		},

		{
			name("Apricot"),
		},

		{
			name("Arbre"),
		},

		{
			name("Arc"),
		},

		{
			name("Arendelle"),
		},

		{
			name("Argile"),
		},

		{
			name("AsciiDots"),
		},

		{
			name("AspectC++"),
		},

		{
			name("AspectJ"),
		},

		{
			name("Assembly"),
		},

		{
			name("Astro"),
		},

		{
			name("Asymptote"),
		},

		{
			name("AutoHotkey"),
		},

		{
			name("AutoIt"),
		},

		{
			name("AutoLISP"),
		},

		{
			name("Axe"),
		},

		{
			name("Axiom"),
		},

		{
			name("Axum"),
		},

		{
			name("B"),
		},

		{
			name("B4J"),
		},

		{
			name("BASIC"),
		},

		{
			name("BASIC256"),
		},

		{
			name("BBC BASIC"),
		},

		{
			name("BCPL"),
		},

		{
			name("BML"),
		},

		{
			name("BaCon"),
		},

		{
			name("Babel"),
		},

		{
			name("Batch File"),
		},

		{
			name("Battlestar"),
		},

		{
			name("Bc"),
		},

		{
			name("Beeswax"),
		},

		{
			name("Befunge"),
		},

		{
			name("Beta"),
		},

		{
			name("Biferno"),
		},

		{
			name("Binary Lambda Calculus"),
		},

		{
			name("Blast"),
		},

		{
			name("BlitzMax"),
		},

		{
			name("Blz"),
		},

		{
			name("Boo"),
		},

		{
			name("Bori"),
		},

		{
			name("Brace"),
		},

		{
			name("Bracmat"),
		},

		{
			name("Brainf***"),
		},

		{
			name("Brat"),
		},

		{
			name("Brlcad"),
		},

		{
			name("Burlesque"),
		},

		{
			name("C"),
			url("https://en.wikipedia.org/wiki/The_C_Programming_Language"),
		},

		{
			name("C Shell"),
		},

		{
			name("C#"),
			url("https://en.wikipedia.org/wiki/C_Sharp_(programming_language)"),
		},

		{
			name("C++"),
			url("https://en.wikipedia.org/wiki/C++"),
		},

		{
			name("C++/CLI"),
		},

		{
			name("C0H"),
		},

		{
			name("C1R"),
		},

		{
			name("CB80"),
		},

		{
			name("CHR"),
		},

		{
			name("CLIPS"),
		},

		{
			name("CMake"),
		},

		{
			name("COBOL"),
		},

		{
			name("Caché ObjectScript"),
		},

		{
			name("CafeOBJ"),
		},

		{
			name("Caml"),
		},

		{
			name("Cat"),
		},

		{
			name("Cduce"),
		},

		{
			name("Cecil"),
		},

		{
			name("Ceylon"),
		},

		{
			name("Chapel"),
		},

		{
			name("Chef"),
		},

		{
			name("ChucK"),
		},

		{
			name("Cilk"),
		},

		{
			name("Cilk++"),
		},

		{
			name("Clarion"),
		},

		{
			name("Clay"),
		},

		{
			name("Clean"),
		},

		{
			name("Clipper"),
		},

		{
			name("Clipper/XBase++"),
		},

		{
			name("Clojure"),
		},

		{
			name("Cobra"),
		},

		{
			name("Coco"),
		},

		{
			name("CoffeeScript"),
		},

		{
			name("ColdFusion"),
		},

		{
			name("Comal"),
		},

		{
			name("Comefrom0x10"),
		},

		{
			name("Commodore BASIC"),
		},

		{
			name("Common Lisp"),
		},

		{
			name("Component Pascal"),
		},

		{
			name("Computer/zero Assembly"),
		},

		{
			name("Coq"),
		},

		{
			name("Crack"),
		},

		{
			name("Crystal"),
		},

		{
			name("Cubescript"),
		},

		{
			name("Curry"),
		},

		{
			name("D"),
		},

		{
			name("DCL"),
		},

		{
			name("DDNC"),
		},

		{
			name("DIV Games Studio"),
		},

		{
			name("DM"),
		},

		{
			name("DMS"),
		},

		{
			name("DUP"),
		},

		{
			name("DWScript"),
		},

		{
			name("Dafny"),
		},

		{
			name("Dao"),
		},

		{
			name("Dart"),
		},

		{
			name("Datalog"),
		},

		{
			name("Dc"),
		},

		{
			name("Delphi"),
		},

		{
			name("Deluge"),
		},

		{
			name("DeviousYarn"),
		},

		{
			name("Diesel"),
		},

		{
			name("Dodo0"),
		},

		{
			name("Dylan"),
		},

		{
			name("Dylan.NET"),
		},

		{
			name("Déjà Vu"),
		},

		{
			name("E"),
		},

		{
			name("EC"),
		},

		{
			name("ECL"),
		},

		{
			name("EDSAC order code"),
		},

		{
			name("EGL"),
		},

		{
			name("ELLA"),
		},

		{
			name("ERRE"),
		},

		{
			name("ESQL"),
		},

		{
			name("EchoLisp"),
		},

		{
			name("Eero"),
		},

		{
			name("Efene"),
		},

		{
			name("Egel"),
		},

		{
			name("Egison"),
		},

		{
			name("EhBASIC"),
		},

		{
			name("Eiffel"),
		},

		{
			name("Ela"),
		},

		{
			name("Elan"),
		},

		{
			name("ElastiC"),
		},

		{
			name("Elena"),
		},

		{
			name("Elisa"),
		},

		{
			name("Elixir"),
		},

		{
			name("Elm"),
		},

		{
			name("Emacs Lisp"),
		},

		{
			name("Emojicode"),
		},

		{
			name("Epigram"),
		},

		{
			name("Erlang"),
		},

		{
			name("Es"),
		},

		{
			name("Euler"),
		},

		{
			name("Euphoria"),
		},

		{
			name("Ezhil"),
		},

		{
			name("F"),
		},

		{
			name("F#"),
		},

		{
			name("FALSE"),
		},

		{
			name("FAUST"),
		},

		{
			name("FBSL"),
		},

		{
			name("FLORA-2"),
		},

		{
			name("FOCAL"),
		},

		{
			name("FP"),
		},

		{
			name("FPI"),
		},

		{
			name("FRISC Assembly"),
		},

		{
			name("FUZE BASIC"),
		},

		{
			name("Factor"),
		},

		{
			name("Falcon"),
		},

		{
			name("Fan"),
		},

		{
			name("Fancy"),
		},

		{
			name("Fantom"),
		},

		{
			name("FeatureC++"),
		},

		{
			name("Felix"),
		},

		{
			name("Ferite"),
		},

		{
			name("Fexl"),
		},

		{
			name("Fish"),
		},

		{
			name("Florid"),
		},

		{
			name("FormulaOne"),
		},

		{
			name("Forth"),
		},

		{
			name("Fortran"),
		},

		{
			name("Fortress"),
		},

		{
			name("Free Pascal"),
		},

		{
			name("FreeBASIC"),
		},

		{
			name("FreeMat"),
		},

		{
			name("Frege"),
		},

		{
			name("Friendly interactive shell"),
		},

		{
			name("Frink"),
		},

		{
			name("FunL"),
		},

		{
			name("Futhark"),
		},

		{
			name("FutureBasic"),
		},

		{
			name("GAP"),
		},

		{
			name("GEORGE"),
		},

		{
			name("GFA Basic"),
		},

		{
			name("GLBasic"),
		},

		{
			name("GLSL"),
		},

		{
			name("GML"),
		},

		{
			name("GUISS"),
		},

		{
			name("GW-BASIC"),
		},

		{
			name("Gambas"),
		},

		{
			name("Gastona"),
		},

		{
			name("Gecho"),
		},

		{
			name("Gema"),
		},

		{
			name("Gentee"),
		},

		{
			name("Genyris"),
		},

		{
			name("Glagol"),
		},

		{
			name("Glee"),
		},

		{
			name("GlovePIE"),
		},

		{
			name("Gnuplot"),
		},

		{
			name("Go"),
			url("https://en.wikipedia.org/wiki/Go_(programming_language)"),
			date("10 November 2009"),
			typing("strong", "static"),
		},

		{
			name("Go!"),
		},

		{
			name("Golfscript"),
		},

		{
			name("Golo"),
		},

		{
			name("Goo"),
		},

		{
			name("Gosu"),
		},

		{
			name("Gri"),
		},

		{
			name("Groovy"),
		},

		{
			name("HLA"),
		},

		{
			name("HPPPL"),
		},

		{
			name("HQ9+"),
		},

		{
			name("Hack"),
		},

		{
			name("Halon"),
		},

		{
			name("Harbour"),
		},

		{
			name("Haskell"),
		},

		{
			name("Haxe"),
		},

		{
			name("Heron"),
		},

		{
			name("HicEst"),
		},

		{
			name("HolyC"),
		},

		{
			name("Hoon"),
		},

		{
			name("Hope"),
		},

		{
			name("Huginn"),
		},

		{
			name("Hy"),
		},

		{
			name("HyperTalk"),
		},

		{
			name("I"),
		},

		{
			name("IDL"),
		},

		{
			name("IWBASIC"),
		},

		{
			name("Icon"),
		},

		{
			name("Idris"),
		},

		{
			name("Inform 6"),
		},

		{
			name("Inform 7"),
		},

		{
			name("Informix 4GL"),
		},

		{
			name("Integer BASIC"),
		},

		{
			name("Intercal"),
		},

		{
			name("Io"),
		},

		{
			name("Ioke"),
		},

		{
			name("Iptscrae"),
		},

		{
			name("J"),
		},

		{
			name("JAMES II/Rule-based Cellular Automata"),
		},

		{
			name("JCL"),
		},

		{
			name("JOVIAL"),
		},

		{
			name("JScript.NET"),
		},

		{
			name("Jabaco"),
		},

		{
			name("Jack"),
		},

		{
			name("Jacquard Loom"),
		},

		{
			name("Java"),
			url("https://en.wikipedia.org/wiki/Java_(programming_language)"),
		},

		{
			name("JavaFX Script"),
		},

		{
			name("JavaScript"),
		},

		{
			name("JoCaml"),
		},

		{
			name("Joy"),
		},

		{
			name("Jq"),
		},

		{
			name("JudoScript"),
		},

		{
			name("Julia"),
		},

		{
			name("K"),
		},

		{
			name("Kamailio Script"),
		},

		{
			name("Kaya"),
		},

		{
			name("KeyList Databasing"),
		},

		{
			name("Kite"),
		},

		{
			name("Kitten"),
		},

		{
			name("Klong"),
		},

		{
			name("KonsolScript"),
		},

		{
			name("Kotlin"),
		},

		{
			name("L++"),
		},

		{
			name("L.in.oleum"),
		},

		{
			name("LC2200 Assembly"),
		},

		{
			name("LC3 Assembly"),
		},

		{
			name("LFE"),
		},

		{
			name("LLP"),
		},

		{
			name("LLVM"),
		},

		{
			name("LOLCODE"),
		},

		{
			name("LSE64"),
		},

		{
			name("LSL"),
		},

		{
			name("LaTeX"),
		},

		{
			name("LabVIEW"),
		},

		{
			name("Lambda Prolog"),
		},

		{
			name("Lambdatalk"),
		},

		{
			name("Lang5"),
		},

		{
			name("Lasso"),
		},

		{
			name("Leon"),
		},

		{
			name("Lhogho"),
		},

		{
			name("Liberty BASIC"),
		},

		{
			name("LibreOffice Basic"),
		},

		{
			name("Lily"),
		},

		{
			name("Lilypond"),
		},

		{
			name("Limbo"),
		},

		{
			name("Lingo"),
		},

		{
			name("Lisaac"),
		},

		{
			name("Lisp"),
		},

		{
			name("LiveCode"),
		},

		{
			name("LiveScript"),
		},

		{
			name("Livecode"),
		},

		{
			name("Lobster"),
		},

		{
			name("Locomotive Basic"),
		},

		{
			name("Loglan82"),
		},

		{
			name("Logo"),
		},

		{
			name("Logtalk"),
		},

		{
			name("Lolli"),
		},

		{
			name("Lotus 123 Macro Scripting"),
		},

		{
			name("LotusScript"),
		},

		{
			name("Lout"),
		},

		{
			name("Lua"),
		},

		{
			name("Lucid"),
		},

		{
			name("Luck"),
		},

		{
			name("Luna"),
		},

		{
			name("Lush"),
		},

		{
			name("Lygon"),
		},

		{
			name("M2000 Interpreter"),
		},

		{
			name("M4"),
		},

		{
			name("M680x0"),
		},

		{
			name("MAPPER"),
		},

		{
			name("MATLAB"),
		},

		{
			name("MAXScript"),
		},

		{
			name("MBS"),
		},

		{
			name("MDL"),
		},

		{
			name("ME10 macro"),
		},

		{
			name("MEL"),
		},

		{
			name("MGS"),
		},

		{
			name("MINIL"),
		},

		{
			name("MIPS Assembly"),
		},

		{
			name("MIRC Scripting Language"),
		},

		{
			name("ML"),
		},

		{
			name("ML/I"),
		},

		{
			name("MLite"),
		},

		{
			name("MMIX"),
		},

		{
			name("MOO"),
		},

		{
			name("MSX Basic"),
		},

		{
			name("MUF"),
		},

		{
			name("MUMPS"),
		},

		{
			name("Make"),
		},

		{
			name("Malbolge"),
		},

		{
			name("Maple"),
		},

		{
			name("MathCortex"),
		},

		{
			name("Mathematica"),
		},

		{
			name("Mathprog"),
		},

		{
			name("Maude"),
		},

		{
			name("Maxima"),
		},

		{
			name("Mercury"),
		},

		{
			name("Metafont"),
		},

		{
			name("Metapost"),
		},

		{
			name("Microsoft Small Basic"),
		},

		{
			name("Mirah"),
		},

		{
			name("Mirelle"),
		},

		{
			name("Modula-2"),
		},

		{
			name("Modula-3"),
		},

		{
			name("Mond"),
		},

		{
			name("Monicelli"),
		},

		{
			name("Monkey"),
		},

		{
			name("Monte"),
		},

		{
			name("MontiLang"),
		},

		{
			name("MoonScript"),
		},

		{
			name("Morfa"),
		},

		{
			name("MySQL"),
		},

		{
			name("Myrddin"),
		},

		{
			name("MyrtleScript"),
		},

		{
			name("Mython"),
		},

		{
			name("Mythryl"),
		},

		{
			name("N/t/roff"),
		},

		{
			name("NASL"),
		},

		{
			name("NESL"),
		},

		{
			name("NGS"),
		},

		{
			name("NQP"),
		},

		{
			name("NSIS"),
		},

		{
			name("Neat"),
		},

		{
			name("Neko"),
		},

		{
			name("Nemerle"),
		},

		{
			name("NetLogo"),
		},

		{
			name("NetRexx"),
		},

		{
			name("NewLISP"),
		},

		{
			name("NewtonScript"),
		},

		{
			name("Nial"),
		},

		{
			name("Nice"),
		},

		{
			name("Nickle"),
		},

		{
			name("Nim"),
		},

		{
			name("Nit"),
		},

		{
			name("Niue"),
		},

		{
			name("Nix"),
		},

		{
			name("OASYS"),
		},

		{
			name("OASYS Assembler"),
		},

		{
			name("OCaml"),
		},

		{
			name("OOC"),
		},

		{
			name("OOCalc"),
		},

		{
			name("OPL"),
		},

		{
			name("Oberon-2"),
		},

		{
			name("Objeck"),
		},

		{
			name("Object Pascal"),
		},

		{
			name("ObjectIcon"),
		},

		{
			name("Objective-C"),
		},

		{
			name("Occam"),
		},

		{
			name("Octave"),
		},

		{
			name("Oforth"),
		},

		{
			name("Ol"),
		},

		{
			name("Omega"),
		},

		{
			name("Onyx"),
		},

		{
			name("OoRexx"),
		},

		{
			name("Opa"),
		},

		{
			name("OpenC++"),
		},

		{
			name("OpenEdge/Progress"),
		},

		{
			name("OpenLisp"),
		},

		{
			name("Openscad"),
		},

		{
			name("Order"),
		},

		{
			name("OxygenBasic"),
		},

		{
			name("Oxygene"),
		},

		{
			name("Oz"),
		},

		{
			name("PARI/GP"),
		},

		{
			name("PASM"),
		},

		{
			name("PDP-11 Assembly"),
		},

		{
			name("PHL"),
		},

		{
			name("PHP"),
			url("https://en.wikipedia.org/wiki/PHP"),
		},

		{
			name("PILOT"),
		},

		{
			name("PIR"),
		},

		{
			name("PL/I"),
		},

		{
			name("PL/M"),
		},

		{
			name("PL/SQL"),
		},

		{
			name("PL/pgSQL"),
		},

		{
			name("PLUS"),
		},

		{
			name("PLZ/SYS"),
		},

		{
			name("POV-Ray"),
		},

		{
			name("PPC Assembly"),
		},

		{
			name("PPL"),
		},

		{
			name("PSQL"),
		},

		{
			name("Panda"),
		},

		{
			name("Panoramic"),
		},

		{
			name("Pare"),
		},

		{
			name("Pascal"),
		},

		{
			name("Peloton"),
		},

		{
			name("Pentium Assembly"),
		},

		{
			name("PeopleCode"),
		},

		{
			name("Perl"),
		},

		{
			name("Perl 6"),
		},

		{
			name("Perl5i"),
		},

		{
			name("Phix"),
		},

		{
			name("Picat"),
		},

		{
			name("PicoLisp"),
		},

		{
			name("Pict"),
		},

		{
			name("Piet"),
		},

		{
			name("Pike"),
		},

		{
			name("PlainTeX"),
		},

		{
			name("Plan"),
		},

		{
			name("Pony"),
		},

		{
			name("Pop11"),
		},

		{
			name("PostScript"),
		},

		{
			name("Potion"),
		},

		{
			name("PowerBASIC"),
		},

		{
			name("PowerShell"),
		},

		{
			name("Powerbuilder"),
		},

		{
			name("ProDOS"),
		},

		{
			name("Processing"),
		},

		{
			name("Prolog"),
		},

		{
			name("Pure"),
		},

		{
			name("Pure Data"),
		},

		{
			name("PureBasic"),
		},

		{
			name("Purity"),
		},

		{
			name("Pyret"),
		},

		{
			name("Python"),
		},

		{
			name("Q"),
		},

		{
			name("Qi"),
		},

		{
			name("Qore"),
		},

		{
			name("QuakeC"),
		},

		{
			name("Quill"),
		},

		{
			name("Quite BASIC"),
		},

		{
			name("R"),
		},

		{
			name("REALbasic"),
		},

		{
			name("REBOL"),
		},

		{
			name("REXX"),
		},

		{
			name("RLSL"),
		},

		{
			name("RLaB"),
		},

		{
			name("RPG"),
		},

		{
			name("RPGIV"),
		},

		{
			name("RPL"),
		},

		{
			name("RPL/2"),
		},

		{
			name("RTL/2"),
		},

		{
			name("RTSL"),
		},

		{
			name("Ra"),
		},

		{
			name("Racket"),
		},

		{
			name("RapidQ"),
		},

		{
			name("Rapira"),
		},

		{
			name("Rascal"),
		},

		{
			name("Raven"),
		},

		{
			name("Reason"),
		},

		{
			name("Red"),
		},

		{
			name("Reduce"),
		},

		{
			name("Refal"),
		},

		{
			name("Retro"),
		},

		{
			name("Rhope"),
		},

		{
			name("Ring"),
		},

		{
			name("Robotic"),
		},

		{
			name("Ruby"),
		},

		{
			name("Rubylog"),
		},

		{
			name("Run BASIC"),
		},

		{
			name("Rust"),
		},

		{
			name("S-lang"),
		},

		{
			name("SAS"),
		},

		{
			name("SETL"),
		},

		{
			name("SIMPOL"),
		},

		{
			name("SMEQL"),
		},

		{
			name("SNOBOL4"),
		},

		{
			name("SNUSP"),
		},

		{
			name("SPAD"),
		},

		{
			name("SPARC Assembly"),
		},

		{
			name("SPARK"),
		},

		{
			name("SPL"),
		},

		{
			name("SQL"),
		},

		{
			name("SQL PL"),
		},

		{
			name("SSEM"),
		},

		{
			name("Sage"),
		},

		{
			name("Salmon"),
		},

		{
			name("Sass/SCSS"),
		},

		{
			name("Sather"),
		},

		{
			name("Scala"),
		},

		{
			name("Scheme"),
		},

		{
			name("Scilab"),
		},

		{
			name("Scratch"),
		},

		{
			name("Script Basic"),
		},

		{
			name("Script3D"),
		},

		{
			name("ScriptBasic"),
		},

		{
			name("Sed"),
		},

		{
			name("Seed7"),
		},

		{
			name("Self"),
		},

		{
			name("SequenceL"),
		},

		{
			name("Set lang"),
		},

		{
			name("Setl4"),
		},

		{
			name("SheerPower 4GL"),
		},

		{
			name("Shen"),
		},

		{
			name("Shiny"),
		},

		{
			name("Sidef"),
		},

		{
			name("SimpleLang"),
		},

		{
			name("Simula"),
		},

		{
			name("Sinclair ZX81 BASIC"),
		},

		{
			name("Sisal"),
		},

		{
			name("SkookumScript"),
		},

		{
			name("Slate"),
		},

		{
			name("Smalltalk"),
		},

		{
			name("Smart BASIC"),
		},

		{
			name("SmileBASIC"),
		},

		{
			name("Snobol"),
		},

		{
			name("Soar"),
		},

		{
			name("SoneKing Assembly"),
		},

		{
			name("Sparkling"),
		},

		{
			name("Spin"),
		},

		{
			name("Squirrel"),
		},

		{
			name("Standard ML"),
		},

		{
			name("Star"),
		},

		{
			name("Stata"),
		},

		{
			name("StreamIt"),
		},

		{
			name("Suneido"),
		},

		{
			name("SuperCollider"),
		},

		{
			name("SuperTalk"),
		},

		{
			name("Superbase BASIC"),
		},

		{
			name("Supernova"),
		},

		{
			name("Swift"),
		},

		{
			name("Symsyn"),
		},

		{
			name("SystemVerilog"),
		},

		{
			name("TAL"),
		},

		{
			name("TI-83 BASIC"),
		},

		{
			name("TI-83 Hex Assembly"),
		},

		{
			name("TI-89 BASIC"),
		},

		{
			name("TIScript"),
		},

		{
			name("TPP"),
		},

		{
			name("TSE SAL"),
		},

		{
			name("TUSCRIPT"),
		},

		{
			name("TXR"),
		},

		{
			name("Tbas"),
		},

		{
			name("Tcl"),
		},

		{
			name("TeLa"),
		},

		{
			name("TechBASIC"),
		},

		{
			name("Teco"),
		},

		{
			name("Terra"),
		},

		{
			name("TestML"),
		},

		{
			name("Thistle"),
		},

		{
			name("Thyrd"),
		},

		{
			name("ToffeeScript"),
		},

		{
			name("Toka"),
		},

		{
			name("TorqueScript"),
		},

		{
			name("TransFORTH"),
		},

		{
			name("Transact-SQL"),
		},

		{
			name("Trith"),
		},

		{
			name("True BASIC"),
		},

		{
			name("Turing"),
		},

		{
			name("Twelf"),
		},

		{
			name("TypeScript"),
		},

		{
			name("UC++"),
		},

		{
			name("UNIX Shell"),
		},

		{
			name("UScript"),
		},

		{
			name("UTFool"),
		},

		{
			name("Unicon"),
		},

		{
			name("Uniface"),
		},

		{
			name("UnixPipes"),
		},

		{
			name("Unlambda"),
		},

		{
			name("Ursa"),
		},

		{
			name("Ursala"),
		},

		{
			name("UserRPL"),
		},

		{
			name("Uyir"),
		},

		{
			name("V"),
		},

		{
			name("VAX Assembly"),
		},

		{
			name("VB6"),
		},

		{
			name("VBA"),
		},

		{
			name("VBScript"),
		},

		{
			name("VHDL"),
		},

		{
			name("VRML"),
		},

		{
			name("Vala"),
		},

		{
			name("Vedit macro language"),
		},

		{
			name("Verbexx"),
		},

		{
			name("Verilog"),
		},

		{
			name("Vim Script"),
		},

		{
			name("Visual Basic"),
		},

		{
			name("Visual Basic .NET"),
		},

		{
			name("Visual FoxPro"),
		},

		{
			name("Visual Objects"),
		},

		{
			name("Visual Prolog"),
		},

		{
			name("Viua VM assembly"),
		},

		{
			name("Vorpal"),
		},

		{
			name("Vox"),
		},

		{
			name("WDTE"),
		},

		{
			name("WML"),
		},

		{
			name("Wart"),
		},

		{
			name("WebAssembly"),
		},

		{
			name("Whenever"),
		},

		{
			name("Whitespace"),
		},

		{
			name("Wolfram Language"),
		},

		{
			name("Wollok"),
		},

		{
			name("Wortel"),
		},

		{
			name("Wrapl"),
		},

		{
			name("Wren"),
		},

		{
			name("X10"),
		},

		{
			name("X86 64 Assembly"),
		},

		{
			name("X86 Assembly"),
		},

		{
			name("XBase"),
		},

		{
			name("XEec"),
		},

		{
			name("XL"),
		},

		{
			name("XLISP"),
		},

		{
			name("XPL0"),
		},

		{
			name("XPath 2.0"),
		},

		{
			name("XProc"),
		},

		{
			name("XQuery"),
		},

		{
			name("XS"),
		},

		{
			name("XSLT"),
		},

		{
			name("XSLT 1.0"),
		},

		{
			name("XSLT 2.0"),
		},

		{
			name("XTalk"),
		},

		{
			name("XUL"),
		},

		{
			name("Xanadu"),
		},

		{
			name("Xojo"),
		},

		{
			name("Ya"),
		},

		{
			name("Yacas"),
		},

		{
			name("Yorick"),
		},

		{
			name("Z80 Assembly"),
		},

		{
			name("ZED"),
		},

		{
			name("ZPL"),
		},

		{
			name("ZX Spectrum Basic"),
		},

		{
			name("Zkl"),
		},

		{
			name("Zonnon"),
		},

		{
			name("ΜC++"),
		},

		{
			name("МК-61/52"),
		},
	}

	var utils initUtils
	// Push programming languages to the global list.
	for _, attrs := range progLangList {
		var lang ProgLang
		for _, attr := range attrs {
			switch v := attr.(type) {
			case langName:
				lang.name = string(v)
			case langURL:
				lang.url = string(v)
			case langDate:
				lang.date = utils.parseDate(string(v))
			case TypeSystem:
				lang.TypeSystem = v
			default:
				panic(fmt.Sprintf("unexpected attr: %#v", v))
			}
		}
		langList = append(langList, &lang)
	}
}
